import axios from "axios";
import React, { useEffect, useState } from "react";
import { formatDate, maskEmail } from "./helpers";

const BASE_URI = "http://localhost:8100/api";
const EMPLOYEES_ENDPOINT = `${BASE_URI}/employees`;
const GET_ALL_EMPLOYEES_URL = EMPLOYEES_ENDPOINT;
const DELETE_EMPLOYEE_URL = EMPLOYEES_ENDPOINT;
const UPDATE_EMPLOYEE_URL = EMPLOYEES_ENDPOINT;

const EmployeeList = () => {
  const [employees, setEmployees] = useState([]);
  const [error, setError] = useState(null);
  const [editEmployeeId, setEditEmployeeId] = useState(null);
  const [editedPhoneNumber, setEditedPhoneNumber] = useState("");

  useEffect(() => {
    fetchData();
  }, []);

  // Fetch all employees
  const fetchData = async () => {
    try {
      const response = await axios.get(GET_ALL_EMPLOYEES_URL);
      const formattedEmployees = response.data.message.map((employee) => ({
        ...employee,
        maskedEmail: maskEmail(employee.email_address),
        dateOfJoining: formatDate(employee.date_of_joining)
      }));
      setEmployees(formattedEmployees);
    } catch (error) {
      setError(error);
    }
  };

  // Handle delete all employees
  const handleDeleteAll = async () => {
    try {
      await axios.delete(DELETE_EMPLOYEE_URL);
      setEmployees([]); // Clear the employees array in the state
    } catch (error) {
      setError(error);
    }
  };

  // Handle delete employee
  const handleDelete = async (id) => {
    try {
      await axios.delete(DELETE_EMPLOYEE_URL + "/" + id);
      //setEmployees(employees.filter((employee) => employee._id !== id));
      fetchData();
    } catch (error) {
      setError(error);
    }
  };

  // Handle update employee
  const handleEdit = (employee) => {
    setEditEmployeeId(employee._id);
    setEditedPhoneNumber(employee.phoneNumber);
  };

  const handleUpdate = async () => {
    try {
      await axios.patch(UPDATE_EMPLOYEE_URL + "/" + editEmployeeId, {
        phone_number: editedPhoneNumber
      });
      fetchData();
      setEditEmployeeId(null);
      setEditedPhoneNumber("");
    } catch (error) {
      setError(error);
    }
  };

  const handleCancel = () => {
    setEditEmployeeId(null);
    setEditedPhoneNumber("");
  };

  // Handle new employee
  const handlePost = () => {
    alert("The handlePost method needs to be implemented.");
  };

  // todo - add post operation

  if (error) {
    return <div>Error: {error}</div>;
  }

  return (
    <div style={styles.container}>
      <h1>Employee List</h1>
      <button style={styles.addButton} onClick={handlePost}>
        Add Employee
      </button>
      {employees.length > 0 ? (
        <>
          <button style={styles.deleteButton} onClick={handleDeleteAll}>
            Delete All
          </button>
          <table style={styles.table}>
            <thead>
              <tr>
                <th style={styles.header}>Index</th>
                <th style={styles.header}>First name</th>
                <th style={styles.header}>Last name</th>
                <th style={styles.header}>Email</th>
                <th style={styles.header}>Phone number</th>
                <th style={styles.header}>Date of joining</th>
                <th style={styles.header}>Actions</th>
                {/* Add more table headers/columns as needed */}
              </tr>
            </thead>
            <tbody>
              {employees.map((employee, index) => (
                <tr key={employee._id} style={styles.row}>
                  <td>{index + 1}</td>
                  <td>{employee.first_name}</td>
                  <td>{employee.last_name}</td>
                  <td>{employee.maskedEmail}</td>
                  <td>
                    {editEmployeeId === employee._id ? (
                      <input
                        type="text"
                        value={editedPhoneNumber}
                        onChange={(e) => setEditedPhoneNumber(e.target.value)}
                        style={styles.deleteInput}
                      />
                    ) : (
                      employee.phone_number
                    )}
                  </td>
                  <td>{employee.dateOfJoining}</td>
                  <td>
                    {editEmployeeId === employee._id ? (
                      <div>
                        <button
                          style={styles.updateButton}
                          onClick={handleUpdate}
                        >
                          Update
                        </button>
                        <button
                          style={styles.cancelButton}
                          onClick={handleCancel}
                        >
                          Cancel
                        </button>
                      </div>
                    ) : (
                      <button
                        style={styles.editButton}
                        onClick={() => handleEdit(employee)}
                      >
                        Edit
                      </button>
                    )}
                    <button
                      style={styles.deleteButton}
                      onClick={() => handleDelete(employee._id)}
                    >
                      <i className="fa fa-trash" aria-hidden="true"></i> Delete
                    </button>
                  </td>
                  {/* Add more table cells/columns as needed */}
                </tr>
              ))}
            </tbody>
          </table>
        </>
      ) : (
        <div style={styles.noRecords}>No records found.</div>
      )}
    </div>
  );
};

export default EmployeeList;

const styles = {
  table: {
    borderCollapse: "collapse",
    width: "100%"
  },
  header: {
    backgroundColor: "#f2f2f2",
    fontWeight: "bold",
    padding: "8px",
    textAlign: "center",
    borderBottom: "1px solid #ddd"
  },
  row: {
    backgroundColor: "#fff"
  },
  noRecords: {
    fontStyle: "italic",
    color: "#888",
    marginTop: "16px"
  },
  deleteButton: {
    backgroundColor: "#f44336",
    color: "#fff",
    padding: "4px 8px",
    border: "none",
    borderRadius: "4px",
    cursor: "pointer"
  },
  editButton: {
    backgroundColor: "#4CAF50",
    color: "#fff",
    padding: "4px 8px",
    border: "none",
    borderRadius: "4px",
    marginRight: "4px",
    cursor: "pointer"
  },
  updateButton: {
    backgroundColor: "#2196F3",
    color: "#fff",
    padding: "4px 8px",
    border: "none",
    borderRadius: "4px",
    marginRight: "4px",
    cursor: "pointer"
  },
  deleteInput: {
    padding: "4px 8px",
    border: "1px solid #ddd",
    borderRadius: "4px",
    marginRight: "4px"
  },
  cancelButton: {
    backgroundColor: "#ccc",
    color: "#fff",
    padding: "4px 8px",
    border: "none",
    borderRadius: "4px",
    marginRight: "4px",
    cursor: "pointer"
  },
  addButton: {
    backgroundColor: "#4caf50",
    color: "#fff",
    padding: "4px 8px",
    display: "inline-block",
    border: "none",
    borderRadius: "4px",
    marginRight: "4px",
    cursor: "pointer"
  },
  container: {
    maxWidth: "auto",
    margin: "0 auto",
    padding: "20px"
  }
};
